==> ejc-bfyjerp-api-3.0.0-20241120.023014-45-sources.jar: com/ejianc/business/oa/vo/SealUseVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 用印申请
 * 
 * @author generator
 * 
 */
public class SealUseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    private Long employeeId; // 保管人id
    private String employeeName; // 保管人name
    private Date date; // 用印日期
    private String name; // 刻章名称
    private String use; // 用途
    private String memo; // 备注
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 项目所属组织
    private String parentOrgCode; // 项目所属组织编码
    private Long sealUnitId; // 加印单位id
    private String sealUnitName; // 加印单位name
    private Long sealTypeId; // 用印类别id
    private String sealTypeName; // 用印类别name
    private Integer docNum; // 文件份数
    private Long docTypeId; // 文件类别id
    private String docTypeName; // 文件类别name
    private String lenderFlag; // 是否外借



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getUse() {
        return use;
    }

    public void setUse(String use) {
        this.use = use;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode="bfyj-market-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getSealUnitId() {
        return sealUnitId;
    }

    @ReferDeserialTransfer
    public void setSealUnitId(Long sealUnitId) {
        this.sealUnitId = sealUnitId;
    }
    public String getSealUnitName() {
        return sealUnitName;
    }

    public void setSealUnitName(String sealUnitName) {
        this.sealUnitName = sealUnitName;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getSealTypeId() {
        return sealTypeId;
    }
    @ReferDeserialTransfer
    public void setSealTypeId(Long sealTypeId) {
        this.sealTypeId = sealTypeId;
    }
    public String getSealTypeName() {
        return sealTypeName;
    }

    public void setSealTypeName(String sealTypeName) {
        this.sealTypeName = sealTypeName;
    }
    public Integer getDocNum() {
        return docNum;
    }

    public void setDocNum(Integer docNum) {
        this.docNum = docNum;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getDocTypeId() {
        return docTypeId;
    }
    @ReferDeserialTransfer
    public void setDocTypeId(Long docTypeId) {
        this.docTypeId = docTypeId;
    }
    public String getDocTypeName() {
        return docTypeName;
    }

    public void setDocTypeName(String docTypeName) {
        this.docTypeName = docTypeName;
    }
    public String getLenderFlag() {
        return lenderFlag;
    }

    public void setLenderFlag(String lenderFlag) {
        this.lenderFlag = lenderFlag;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20241120.030831-46-sources.jar: com/ejianc/business/oa/vo/SealUseVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 用印申请
 * 
 * @author generator
 * 
 */
public class SealUseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    private Long employeeId; // 保管人id
    private String employeeName; // 保管人name
    private Date date; // 用印日期
    private String name; // 刻章名称
    private String purpose; // 用途
    private String memo; // 备注
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 项目所属组织
    private String parentOrgCode; // 项目所属组织编码
    private Long sealUnitId; // 加印单位id
    private String sealUnitName; // 加印单位name
    private Long sealTypeId; // 用印类别id
    private String sealTypeName; // 用印类别name
    private Integer docNum; // 文件份数
    private Long docTypeId; // 文件类别id
    private String docTypeName; // 文件类别name
    private String lenderFlag; // 是否外借



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPurpose() {
        return purpose;
    }

    public void setPurpose(String purpose) {
        this.purpose = purpose;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode="bfyj-market-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getSealUnitId() {
        return sealUnitId;
    }

    @ReferDeserialTransfer
    public void setSealUnitId(Long sealUnitId) {
        this.sealUnitId = sealUnitId;
    }
    public String getSealUnitName() {
        return sealUnitName;
    }

    public void setSealUnitName(String sealUnitName) {
        this.sealUnitName = sealUnitName;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getSealTypeId() {
        return sealTypeId;
    }
    @ReferDeserialTransfer
    public void setSealTypeId(Long sealTypeId) {
        this.sealTypeId = sealTypeId;
    }
    public String getSealTypeName() {
        return sealTypeName;
    }

    public void setSealTypeName(String sealTypeName) {
        this.sealTypeName = sealTypeName;
    }
    public Integer getDocNum() {
        return docNum;
    }

    public void setDocNum(Integer docNum) {
        this.docNum = docNum;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getDocTypeId() {
        return docTypeId;
    }
    @ReferDeserialTransfer
    public void setDocTypeId(Long docTypeId) {
        this.docTypeId = docTypeId;
    }
    public String getDocTypeName() {
        return docTypeName;
    }

    public void setDocTypeName(String docTypeName) {
        this.docTypeName = docTypeName;
    }
    public String getLenderFlag() {
        return lenderFlag;
    }

    public void setLenderFlag(String lenderFlag) {
        this.lenderFlag = lenderFlag;
    }
    
}
